"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Button;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _constants = require("../constants");

var _stringUtils = require("../utils/string-utils");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var disabledStyles = (0, _styledComponents.css)(["background-color:", ";&&{cursor:default;}"], _constants.COLOR_GRAY_BLUE);
/**
 * Returns `null` if an icon node is not provided. Otherwise, it returns a
 * styled <Icon /> component.
 */

function buttonIcon(_ref) {
  var icon = _ref.icon,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'default' : _ref$type,
      _ref$iconOnly = _ref.iconOnly,
      iconOnly = _ref$iconOnly === void 0 ? false : _ref$iconOnly;

  if (!icon) {
    return null;
  }

  var Icon = (0, _styledComponents.default)(icon).attrs(function () {
    return {
      dark: type !== 'link'
    };
  }).withConfig({
    displayName: "Button__Icon",
    componentId: "lsnwxn-0"
  })(["margin-right:", ";vertical-align:middle;&& svg{font-size:1.125em;}"], iconOnly ? 0 : '1.125em');
  return _react.default.createElement(Icon, null);
}
/** Linear gradient value builder for the `background` property. */


function linearGradient(colors) {
  return "linear-gradient(to right, ".concat(colors, ")");
}

var BasicButton = _styledComponents.default.div.attrs(function (_ref2) {
  var text = _ref2.text;
  return {
    children: text,
    role: 'button'
  };
}).withConfig({
  displayName: "Button__BasicButton",
  componentId: "lsnwxn-1"
})(["border:0;outline:none;user-select:none;display:inline-block;text-align:center;vertical-align:middle;background:", ";color:", ";text-transform:uppercase;border-radius:0.375em;padding:1em;font-size:", ";font-weight:500;overflow:hidden;position:relative;&:hover{cursor:pointer;}", ""], function (_ref3) {
  var type = _ref3.type;
  return type === 'link' ? 'transparent' : _constants.COLOR_PRIMARY;
}, function (_ref4) {
  var type = _ref4.type;
  return type === 'link' ? _constants.COLOR_PRIMARY : _constants.COLOR_WHITE;
}, (0, _stringUtils.styleLengths)(_constants.TYPE_FONT_SIZE_HEADING_6), function (_ref5) {
  var disabled = _ref5.disabled;
  return disabled && disabledStyles;
});

var IconOnlyButton = (0, _styledComponents.default)(BasicButton).attrs(function (_ref6) {
  var icon = _ref6.icon;
  return {
    children: buttonIcon({
      icon: icon,
      iconOnly: true
    })
  };
}).withConfig({
  displayName: "Button__IconOnlyButton",
  componentId: "lsnwxn-2"
})(["border-radius:50%;"]);
var WideButton = (0, _styledComponents.default)(BasicButton).withConfig({
  displayName: "Button__WideButton",
  componentId: "lsnwxn-3"
})(["display:flex;flex-direction:row;align-items:center;justify-content:center;background:", ";color:", ";border-radius:", ";min-height:4em;margin:", ";"], function (_ref7) {
  var type = _ref7.type,
      disabled = _ref7.disabled;

  if (disabled) {
    return type === 'link' ? 'transparent' : _constants.COLOR_GRAY_BLUE;
  }

  return type === 'link' ? 'transparent' : linearGradient(_constants.GRADIENT_PRIMARY);
}, function (_ref8) {
  var type = _ref8.type,
      disabled = _ref8.disabled,
      darkMode = _ref8.theme.darkMode;

  if (type === 'link') {
    if (disabled) {
      return 'inherit';
    }

    return darkMode ? 'inherit' : _constants.COLOR_PRIMARY;
  }

  return _constants.COLOR_WHITE;
}, function (_ref9) {
  var block = _ref9.block;
  return block ? 0 : '0.375em';
}, function (_ref10) {
  var block = _ref10.block;
  return block ? 0 : '1.25em 1.875em';
});
/**
 * Button signals to the user that an action can be performed by clicking or
 * taping this element.
 */

function Button(_ref11) {
  var basic = _ref11.basic,
      text = _ref11.text,
      block = _ref11.block,
      type = _ref11.type,
      icon = _ref11.icon,
      iconOnly = _ref11.iconOnly,
      props = _objectWithoutProperties(_ref11, ["basic", "text", "block", "type", "icon", "iconOnly"]);

  if (props.disabled) {
    props.onClick = undefined;
  }

  if (iconOnly) {
    return _react.default.createElement(IconOnlyButton, Object.assign({
      icon: icon
    }, props));
  }

  if (basic) {
    return _react.default.createElement(BasicButton, Object.assign({
      text: text,
      type: type
    }, props));
  }

  return _react.default.createElement(WideButton, Object.assign({
    block: block,
    type: type
  }, props), buttonIcon({
    icon: icon,
    type: type
  }), " ", text);
}

Button.defaultProps = {
  basic: false,
  block: false,
  color: 'default',
  icon: null,
  iconOnly: false,
  type: 'default',
  disabled: false
};