"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseType = parseType;
exports.PROPTYPE_CUSTOM = exports.PROPTYPE_INSTANCE_OF = exports.PROPTYPE_ENUM = exports.PROPTYPE_UNION = exports.PROPTYPE_SIMPLE = void 0;
var PROPTYPE_SIMPLE = 'simple';
exports.PROPTYPE_SIMPLE = PROPTYPE_SIMPLE;
var PROPTYPE_UNION = 'union';
exports.PROPTYPE_UNION = PROPTYPE_UNION;
var PROPTYPE_ENUM = 'enum';
exports.PROPTYPE_ENUM = PROPTYPE_ENUM;
var PROPTYPE_INSTANCE_OF = 'instanceOf';
exports.PROPTYPE_INSTANCE_OF = PROPTYPE_INSTANCE_OF;
var PROPTYPE_CUSTOM = 'custom';
/**
 * Accepts a `react-docgen` type and returns an array containing the parsed
 * types. Returns an empty array if type cannot be parsed.
 */

exports.PROPTYPE_CUSTOM = PROPTYPE_CUSTOM;

function parseType(type) {
  var name = type.name,
      value = type.value;

  if (!name) {
    return [];
  }

  switch (name) {
    case PROPTYPE_ENUM:
      return parseEnum(value);

    case PROPTYPE_UNION:
      return parseUnion(value);

    case PROPTYPE_INSTANCE_OF:
      return parseInstanceOf(value);

    case PROPTYPE_CUSTOM:
    default:
      return [parseCustomOrSimple(type)];
  }
}

function parseEnum() {
  var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  return value.map(function (v) {
    return v.value.replace(/'/g, '');
  });
}

function parseUnion() {
  var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  return value.map(function (v) {
    if (v.name === 'arrayOf') {
      return "".concat(v.value.name, "[]");
    }

    return parseCustomOrSimple(v);
  });
}

function parseInstanceOf() {
  var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return [value];
}

function parseCustomOrSimple() {
  var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return value.name === PROPTYPE_CUSTOM ? value.raw : value.name;
}